@@ -1,7 +1,7 @@
 /****************************************************************************
-** $Id: qt/application.cpp   3.3.5   edited Aug 31 12:13 $
+** $Id: qt/application.cpp   3.3.8   edited Jan 11 14:37 $
 **
-** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
 ** program may be used, distributed and modified without limitation.
@@ -252,15 +252,13 @@ void ApplicationWindow::tileHorizontal()
     if ( !windows.count() )
 	return;
 
+    if (ws->activeWindow())
+        ws->activeWindow()->showNormal();
+
     int heightForEach = ws->height() / windows.count();
     int y = 0;
     for ( int i = 0; i < int(windows.count()); ++i ) {
 	QWidget *window = windows.at(i);
-	if ( window->testWState( WState_Maximized ) ) {
-	    // prevent flicker
-	    window->hide();
-	    window->showNormal();
-	}
 	int preferredHeight = window->minimumHeight()+window->parentWidget()->baseSize().height();
 	int actHeight = QMAX(heightForEach, preferredHeight);
 
