@@ -1,7 +1,7 @@
 /****************************************************************************
-** $Id: qt/archivedialog.ui.h   3.3.7   edited Aug 31 2005 $
+** $Id: qt/archivedialog.ui.h   3.3.8   edited Jan 29 15:54 $
 **
-** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA.  All rights reserved.
 **
 ** This file is part of an example program for Qt.  This example
 ** program may be used, distributed and modified without limitation.
@@ -62,10 +62,10 @@ void ArchiveDialog::search()
     } else {
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
     
-	articleSearcher.setHost("www.trolltech.com");
+	articleSearcher.setHost("lists.trolltech.com");
     
-	QHttpRequestHeader header("POST", "/search.html");
-	header.setValue("Host", "www.trolltech.com");
+	QHttpRequestHeader header("POST", "/qt-interest/search.php");
+	header.setValue("Host", "lists.trolltech.com");
 	header.setContentType("application/x-www-form-urlencoded");
     
 	QString encodedTopic = myLineEdit->text();
